
.. _api:

coordio Reference
=================

High Level Utility Functions
------------------------------
.. automodule:: coordio.utils
   :members:
   :undoc-members:
   :show-inheritance:

SOFA
----

.. automodule:: coordio.sofa_bindings
   :members:
   :undoc-members:
   :show-inheritance:

Site
----

.. automodule:: coordio.site
   :members:
   :undoc-members:
   :show-inheritance:

IERS
----

.. automodule:: coordio.iers
   :members:
   :undoc-members:
   :show-inheritance:

Time
----

.. automodule:: coordio.time
   :members:
   :undoc-members:
   :show-inheritance:

Coordinates
-----------

.. automodule:: coordio.coordinate
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.sky
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.telescope
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.wok
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.tangent
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.guide
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: coordio.positioner
   :members:
   :undoc-members:
   :show-inheritance:

Conversions
-------------

.. automodule:: coordio.conv
   :members:
   :undoc-members:
   :show-inheritance:
